@@ -57,6 +57,10 @@ def custom_id(path: Path, file_id: Identification) -> Identification:
             file_id.warning = "Extension mismatch"
         else:
             file_id.warning = None
+    elif path.suffix.lower() == ".id":
+        file_id.puid = "aca-fmt/7"
+        file_id.signature = "ID File"
+        file_id.warning = "Match on extension only"
     elif sig_nsf_bof.search(bof) and sig_nsf_eof.search(eof):
         file_id.puid = "aca-fmt/8"
         file_id.signature = "Lotus Notes Database"
@@ -160,9 +164,9 @@ def update_file_info(
     new_id: Identification = id_info.get(file_info.path) or no_id
     if file_info.path.stat().st_size == 0:
         new_id = Identification(
-            puid=None,
-            signature=None,
-            warning="File is empty.",
+            puid="aca-error/1",
+            signature="Empty file",
+            warning="Error: File is empty",
         )
     file_info = file_info.copy(update=new_id.dict())
     return file_info
